@@ -3,14 +3,10 @@ package Log::Dispatch::ApacheLog;
 use strict;
 use warnings;
 
-our $VERSION = '2.57';
+our $VERSION = '2.60';
 
-use Log::Dispatch::Output;
-
-use base qw( Log::Dispatch::Output );
-
-use Params::Validate qw(validate);
-Params::Validate::validation_options( allow_extra => 1 );
+use Log::Dispatch::Types;
+use Params::ValidationCompiler qw( validation_for );
 
 BEGIN {
     if ( $ENV{MOD_PERL} && $ENV{MOD_PERL} =~ /2\./ ) {
@@ -21,18 +17,23 @@ BEGIN {
     }
 }
 
-sub new {
-    my $proto = shift;
-    my $class = ref $proto || $proto;
+use base qw( Log::Dispatch::Output );
 
-    my %p = validate( @_, { apache => { can => 'log' } } );
+{
+    my $validator = validation_for(
+        params => { apache => { type => t('ApacheLog') } },
+        slurpy => 1,
+    );
 
-    my $self = bless {}, $class;
+    sub new {
+        my $class = shift;
+        my %p     = validator->(@_);
 
-    $self->_basic_init(%p);
-    $self->{apache_log} = $p{apache}->log;
+        my $self = bless { apache_log => ( delete $p{apache} )->log }, $class;
+        $self->_basic_init(%p);
 
-    return $self;
+        return $self;
+    }
 }
 
 {
@@ -70,7 +71,7 @@ Log::Dispatch::ApacheLog - Object for logging to Apache::Log objects
 
 =head1 VERSION
 
-version 2.57
+version 2.60
 
 =head1 SYNOPSIS
 
@@ -104,10 +105,13 @@ An object of either the L<Apache> or L<Apache::Server> classes. Required.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
-(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/houseabsolute/Log-Dispatch/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Log-Dispatch can be found at L<https://github.com/houseabsolute/Log-Dispatch>.
 
 =head1 AUTHOR
 
@@ -115,10 +119,13 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
