@@ -3,55 +3,53 @@ package Log::Dispatch::Email;
 use strict;
 use warnings;
 
-our $VERSION = '2.57';
+our $VERSION = '2.60';
 
-use Log::Dispatch::Output;
+use Devel::GlobalDestruction qw( in_global_destruction );
+use Log::Dispatch::Types;
+use Params::ValidationCompiler qw( validation_for );
 
 use base qw( Log::Dispatch::Output );
 
-use Devel::GlobalDestruction qw( in_global_destruction );
-use Params::Validate qw(validate SCALAR ARRAYREF BOOLEAN);
-Params::Validate::validation_options( allow_extra => 1 );
+{
+    # need to untaint this value
+    my ($program) = $0 =~ /(.+)/;
 
-# need to untaint this value
-my ($program) = $0 =~ /(.+)/;
-
-sub new {
-    my $proto = shift;
-    my $class = ref $proto || $proto;
-
-    my %p = validate(
-        @_, {
+    my $validator = validation_for(
+        params => {
             subject => {
-                type    => SCALAR,
-                default => "$program: log email"
+                type    => t('Str'),
+                default => "$program: log email",
             },
-            to   => { type => SCALAR | ARRAYREF },
+            to   => { type => t('ArrayOfAddresses') },
             from => {
-                type     => SCALAR,
-                optional => 1
+                type     => t('SimpleStr'),
+                optional => 1,
             },
             buffered => {
-                type    => BOOLEAN,
-                default => 1
+                type    => t('Bool'),
+                default => 1,
             },
-        }
+        },
+        slurpy => 1,
     );
 
-    my $self = bless {}, $class;
+    sub new {
+        my $class = shift;
+        my %p     = $validator->(@_);
 
-    $self->_basic_init(%p);
+        my $self = bless {
+            subject  => delete $p{subject},
+            to       => delete $p{to},
+            from     => delete $p{from},
+            buffered => delete $p{buffered},
+        }, $class;
+        $self->{buffer} = [] if $self->{buffered};
 
-    $self->{subject} = $p{subject} || "$0: log email";
-    $self->{to} = ref $p{to} ? $p{to} : [ $p{to} ];
-    $self->{from} = $p{from};
+        $self->_basic_init(%p);
 
-    # Default to buffered for obvious reasons!
-    $self->{buffered} = $p{buffered};
-
-    $self->{buffer} = [] if $self->{buffered};
-
-    return $self;
+        return $self;
+    }
 }
 
 sub log_message {
@@ -77,7 +75,7 @@ sub flush {
     my $self = shift;
 
     if ( $self->{buffered} && @{ $self->{buffer} } ) {
-        my $message = join '', @{ $self->{buffer} };
+        my $message = join q{}, @{ $self->{buffer} };
 
         $self->send_email( message => $message );
         $self->{buffer} = [];
@@ -119,7 +117,7 @@ Log::Dispatch::Email - Base class for objects that send log messages via email
 
 =head1 VERSION
 
-version 2.57
+version 2.60
 
 =head1 SYNOPSIS
 
@@ -140,7 +138,7 @@ version 2.57
 This module should be used as a base class to implement
 Log::Dispatch::* objects that send their log messages via email.
 Implementing a subclass simply requires the code shown in the
-L<SYNOPSIS> with a real implementation of the C<send_email()> method.
+L</SYNOPSIS> with a real implementation of the C<send_email()> method.
 
 =for Pod::Coverage new log_message
 
@@ -196,10 +194,13 @@ email.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
-(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/houseabsolute/Log-Dispatch/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Log-Dispatch can be found at L<https://github.com/houseabsolute/Log-Dispatch>.
 
 =head1 AUTHOR
 
@@ -207,10 +208,13 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
