@@ -3,14 +3,12 @@ package Log::Dispatch::Email::MIMELite;
 use strict;
 use warnings;
 
-our $VERSION = '2.58';
-
-use Log::Dispatch::Email;
-
-use base qw( Log::Dispatch::Email );
+our $VERSION = '2.60';
 
 use MIME::Lite;
 
+use base qw( Log::Dispatch::Email );
+
 sub send_email {
     my $self = shift;
     my %p    = @_;
@@ -24,9 +22,9 @@ sub send_email {
 
     $mail{From} = $self->{from} if defined $self->{from};
 
-    local $?;
+    local $? = undef;
     unless ( MIME::Lite->new(%mail)->send ) {
-        warn "Error sending mail with MIME::Lite";
+        warn 'Error sending mail with MIME::Lite';
     }
 }
 
@@ -46,7 +44,7 @@ Log::Dispatch::Email::MIMELite - Subclass of Log::Dispatch::Email that uses the
 
 =head1 VERSION
 
-version 2.58
+version 2.60
 
 =head1 SYNOPSIS
 
@@ -72,20 +70,27 @@ send_email method using the L<MIME::Lite> module.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<https://github.com/houseabsolute/Log-Dispatch/issues>.
+Bugs may be submitted at L<https://github.com/houseabsolute/Log-Dispatch/issues>.
 
 I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
+=head1 SOURCE
+
+The source code repository for Log-Dispatch can be found at L<https://github.com/houseabsolute/Log-Dispatch>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
