@@ -3,13 +3,12 @@ package Log::Dispatch::Email::MailSend;
 use strict;
 use warnings;
 
-our $VERSION = '2.57';
-
-use Log::Dispatch::Email;
-
-use base qw( Log::Dispatch::Email );
+our $VERSION = '2.60';
 
 use Mail::Send;
+use Try::Tiny;
+
+use base qw( Log::Dispatch::Email );
 
 sub send_email {
     my $self = shift;
@@ -23,17 +22,20 @@ sub send_email {
     # Does this ever work for this module?
     $msg->set( 'From', $self->{from} ) if $self->{from};
 
-    local ( $?, $@, $SIG{__DIE__} );
-    eval {
+    local $? = undef;
+    return
+        if try {
         my $fh = $msg->open
-            or die "Cannot open handle to mail program";
+            or die 'Cannot open handle to mail program';
 
         $fh->print( $p{message} )
-            or die "Cannot print message to mail program handle";
+            or die 'Cannot print message to mail program handle';
 
         $fh->close
-            or die "Cannot close handle to mail program";
-    };
+            or die 'Cannot close handle to mail program';
+
+        1;
+        };
 
     warn $@ if $@;
 }
@@ -54,7 +56,7 @@ Log::Dispatch::Email::MailSend - Subclass of Log::Dispatch::Email that uses the
 
 =head1 VERSION
 
-version 2.57
+version 2.60
 
 =head1 SYNOPSIS
 
@@ -71,7 +73,7 @@ version 2.57
       ],
   );
 
-  $log->emerg("Something bad is happening");
+  $log->emerg('Something bad is happening');
 
 =head1 DESCRIPTION
 
@@ -91,10 +93,13 @@ For more details, see the L<Mail::Mailer> docs.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
-(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/houseabsolute/Log-Dispatch/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Log-Dispatch can be found at L<https://github.com/houseabsolute/Log-Dispatch>.
 
 =head1 AUTHOR
 
@@ -102,10 +107,13 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
