@@ -3,38 +3,41 @@ package Log::Dispatch::Screen;
 use strict;
 use warnings;
 
-our $VERSION = '2.58';
-
-use Log::Dispatch::Output;
-
-use base qw( Log::Dispatch::Output );
+our $VERSION = '2.60';
 
 use Encode qw( encode );
 use IO::Handle;
-use Params::Validate qw(validate BOOLEAN);
-Params::Validate::validation_options( allow_extra => 1 );
+use Log::Dispatch::Types;
+use Params::ValidationCompiler qw( validation_for );
 
-sub new {
-    my $proto = shift;
-    my $class = ref $proto || $proto;
+use base qw( Log::Dispatch::Output );
 
-    my %p = validate(
-        @_, {
+{
+    my $validator = validation_for(
+        params => {
             stderr => {
-                type    => BOOLEAN,
+                type    => t('Bool'),
                 default => 1,
             },
             utf8 => {
-                type    => BOOLEAN,
+                type    => t('Bool'),
                 default => 0,
             },
-        }
+        },
+        slurpy => 1,
     );
 
-    my $self = bless \%p, $class;
-    $self->_basic_init(%p);
+    sub new {
+        my $class = shift;
+        my %p     = $validator->(@_);
 
-    return $self;
+        my $self = bless { map { $_ => delete $p{$_} } qw( stderr utf8 ) },
+            $class;
+
+        $self->_basic_init(%p);
+
+        return $self;
+    }
 }
 
 sub log_message {
@@ -47,6 +50,8 @@ sub log_message {
     # or 2 and use that.
     my $message
         = $self->{utf8} ? encode( 'UTF-8', $p{message} ) : $p{message};
+
+    ## no critic (InputOutput::RequireCheckedSyscalls)
     if ( $self->{stderr} ) {
         print STDERR $message;
     }
@@ -71,7 +76,7 @@ Log::Dispatch::Screen - Object for logging to the screen
 
 =head1 VERSION
 
-version 2.58
+version 2.60
 
 =head1 SYNOPSIS
 
@@ -129,20 +134,27 @@ This defaults to false.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<https://github.com/houseabsolute/Log-Dispatch/issues>.
+Bugs may be submitted at L<https://github.com/houseabsolute/Log-Dispatch/issues>.
 
 I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
+=head1 SOURCE
+
+The source code repository for Log-Dispatch can be found at L<https://github.com/houseabsolute/Log-Dispatch>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
