@@ -3,7 +3,7 @@ package Log::Dispatch::Vars;
 use strict;
 use warnings;
 
-our $VERSION = '2.57';
+our $VERSION = '2.60';
 
 use Exporter qw( import );
 
@@ -13,6 +13,7 @@ our @EXPORT_OK = qw(
     @OrderedLevels
 );
 
+## no critic (Variables::ProhibitPackageVars)
 our %CanonicalLevelNames = (
     (
         map { $_ => $_ }
@@ -49,7 +50,7 @@ our %LevelNamesToNumbers = (
     warn  => 3,
     err   => 4,
     crit  => 5,
-    emerg => 7
+    emerg => 7,
 );
 
 1;
@@ -68,7 +69,7 @@ Log::Dispatch::Vars - Variables used internally by multiple packages
 
 =head1 VERSION
 
-version 2.57
+version 2.60
 
 =head1 DESCRIPTION
 
@@ -76,10 +77,13 @@ There are no user-facing parts here.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Log-Dispatch>
-(or L<bug-log-dispatch@rt.cpan.org|mailto:bug-log-dispatch@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/houseabsolute/Log-Dispatch/issues>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for Log-Dispatch can be found at L<https://github.com/houseabsolute/Log-Dispatch>.
 
 =head1 AUTHOR
 
@@ -87,10 +91,13 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2017 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
